"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const routes_1 = require("../routes");
const clientCookieManager_1 = require("./clientCookieManager");
const utils_1 = require("../utils");
const constants_1 = require("../constants/constants");
class Client {
    /**
     * @param {ClientOptions} options - The options to use.
     */
    constructor(options) {
        Object.defineProperty(this, "dailyReward", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "gameRecordCard", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "sprialAbyss", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "genshinActivity", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "characters", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "genshinUser", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "realTimeNotes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "travelDiary", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "redeemCode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "tcg", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "logined", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.options = {
            language: options?.language || "en-us" /* Language.EnglishUS */,
            cookieManager: options?.cookieManager || new clientCookieManager_1.ClientCookieManager(),
            cacheOptions: {
                maxAge: options?.cacheOptions?.maxAge ?? 60,
                maxSize: options?.cacheOptions?.maxSize,
            },
            debug: options?.debug || false,
        };
        this.cookieManager = this.options.cookieManager;
        this.logined = false;
        (0, utils_1.setDebug)(this.options.debug);
    }
    login(ltuid, ltoken) {
        if (this.isLogin())
            return this;
        this.cookieManager.setCookie(ltuid, ltoken);
        const option = {
            cacheOptions: {
                maxSize: this.options.cacheOptions.maxSize,
            },
            defaultOptions: {
                language: this.options.language,
                cookie: this.cookieManager.get().cookie,
            },
            cookieManager: this.cookieManager,
        };
        this.dailyReward = new routes_1.DailyRewards(option);
        this.genshinActivity = new routes_1.Activities(option);
        this.gameRecordCard = new routes_1.GameRecordCard(option);
        this.sprialAbyss = new routes_1.SpiralAbyss(option);
        this.genshinUser = new routes_1.GenshinUser(option);
        this.realTimeNotes = new routes_1.RealTimeNotes(option);
        this.characters = new routes_1.Charcters(option);
        this.travelDiary = new routes_1.TravelerDiary(option);
        this.tcg = new routes_1.TCG(option);
        this.redeemCode = new routes_1.RedeemCode();
        this.initSweeper();
        this.logined = true;
        return this;
    }
    addCookies(cookies) {
        for (const cookie of cookies) {
            this.cookieManager.setCookie(cookie.ltuid, cookie.ltoken);
        }
    }
    isLogin() {
        return this.logined;
    }
    initSweeper() {
        setInterval(() => {
            if (this.options.debug)
                console.log("[DEBUG] Sweeping cache");
            const filter = v => v.timestamp + this.options.cacheOptions.maxAge < Date.now() ||
                (this.options.cacheOptions.maxSize !== undefined ? v.size > this.options.cacheOptions.maxSize : false);
            for (const cache of (0, constants_1.cacheKeys)(this)) {
                cache.sweep(filter);
            }
        }, 1000 * this.options.cacheOptions.maxAge).unref();
    }
}
exports.Client = Client;
