"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedeemCode = void 0;
const constants_1 = require("../constants/constants");
const utils_1 = require("../utils");
class RedeemCode {
    /**
     * @description Redeem the code
     * @param {string} code The code to redeem
     */
    async redeem(code, options) {
        if (!(0, utils_1.redeemValidator)(code, options)) {
            throw new Error("No code or Cookie provided");
        }
        const { language, uid, cookie } = options;
        const cookieObj = (0, utils_1.CookieToObj)((0, utils_1.CookieObjToString)(cookie) ?? "");
        const version = cookieObj.cookie_token_v2 ? 2 : 1;
        const redeemCookie = version === 2
            ? `cookie_token_v2=${cookieObj.cookie_token_v2}; account_id_v2=${cookieObj.account_id_v2};`
            : `cookie_token=${cookieObj.cookie_token}; account_id=${cookieObj.account_id};`;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_Redeem_Code,
        });
        const res = await instance.get("", {
            Cookie: redeemCookie,
        }, {
            uid: uid,
            region: (0, utils_1.checkServerRegion)(uid),
            lang: language,
            cdkey: code,
            game_biz: "hk4e_global",
        });
        const { data } = res;
        const isSuccessful = data.msg === "Redeemed successfully!";
        return {
            success: isSuccessful,
            msg: data.msg,
            special_shipping: data.special_shipping,
        };
    }
}
exports.RedeemCode = RedeemCode;
