"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TravelerDiary = void 0;
const base_1 = require("./base");
const constants_1 = require("../constants/constants");
const utils_1 = require("../utils");
class TravelerDiary extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Diary,
        });
        const res = await instance.get("month_info", {
            Cookie: cookie,
        }, {
            region: (0, utils_1.checkServerRegion)(uid),
            uid: uid,
            lang: language,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
    async fetchMonth(uid, options) {
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        }, utils_1.OptionType.MonthDiaryOptions);
        if (!(0, utils_1.getMonthValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, month } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Diary,
        });
        const res = await instance.get("month_info", {
            Cookie: cookie,
        }, {
            region: (0, utils_1.checkServerRegion)(uid),
            uid: uid,
            lang: language,
            month: month,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(`${uid}-${month}`, data);
        }
        return data;
    }
}
exports.TravelerDiary = TravelerDiary;
