"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeOptions = exports.OptionType = void 0;
const cookie_1 = require("./cookie");
var OptionType;
(function (OptionType) {
    OptionType["FetchOptions"] = "FetchOptions";
    OptionType["SpiralAbyssFetchOptions"] = "SpiralAbyssFetchOptions";
    OptionType["FetchClaimHistoryOption"] = "FetchClaimHistoryOption";
    OptionType["CardListOptions"] = "CardListOptions";
    OptionType["MonthDiaryOptions"] = "MonthDiaryOptions";
})(OptionType || (exports.OptionType = OptionType = {}));
function mergeOptions(input, type = OptionType.FetchOptions) {
    const options = input.options;
    const cookieManager = input.cookieManager;
    const defaultOptions = input.defaultOptions;
    const cookie = (0, cookie_1.CookieObjToString)(options?.cookie) ?? cookieManager?.get().cookie ?? (0, cookie_1.CookieObjToString)(defaultOptions?.cookie);
    const language = options?.language ?? defaultOptions?.language ?? "en-us" /* Language.EnglishUS */;
    switch (type) {
        case OptionType.SpiralAbyssFetchOptions: {
            const options = input.options;
            return {
                cookie,
                language,
                previous: options?.previous,
            };
        }
        case OptionType.FetchClaimHistoryOption: {
            const options = input.options;
            return {
                cookie,
                language,
                page: options?.page,
            };
        }
        case OptionType.CardListOptions: {
            const options = input.options;
            const { need_avatar, need_action, need_stats, offset, limit } = options ?? {};
            return {
                cookie,
                language,
                need_avatar,
                need_action,
                need_stats,
                offset,
                limit,
            };
        }
        case OptionType.MonthDiaryOptions: {
            const options = input.options;
            const { month } = options ?? {};
            return {
                cookie,
                language,
                month,
            };
        }
        default: {
            return {
                cookie,
                language,
            };
        }
    }
}
exports.mergeOptions = mergeOptions;
